from __future__ import annotations

import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.user import User


T = TypeVar("T", bound="UserFileView")


@_attrs_define
class UserFileView:
    """
    Attributes:
        name (str):
        file_download (str):
        preview (str):
        file_size_kb (int):
        created_by (User): Adds nested create feature
        created_at (datetime.datetime):
        id (int | Unset):
    """

    name: str
    file_download: str
    preview: str
    file_size_kb: int
    created_by: User
    created_at: datetime.datetime
    id: int | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        name = self.name

        file_download = self.file_download

        preview = self.preview

        file_size_kb = self.file_size_kb

        created_by = self.created_by.to_dict()

        created_at = self.created_at.isoformat()

        id = self.id

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "file_download": file_download,
                "preview": preview,
                "file_size_kb": file_size_kb,
                "created_by": created_by,
                "created_at": created_at,
            }
        )
        if id is not UNSET:
            field_dict["id"] = id

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.user import User

        d = dict(src_dict)
        name = d.pop("name")

        file_download = d.pop("file_download")

        preview = d.pop("preview")

        file_size_kb = d.pop("file_size_kb")

        created_by = User.from_dict(d.pop("created_by"))

        created_at = isoparse(d.pop("created_at"))

        id = d.pop("id", UNSET)

        user_file_view = cls(
            name=name,
            file_download=file_download,
            preview=preview,
            file_size_kb=file_size_kb,
            created_by=created_by,
            created_at=created_at,
            id=id,
        )

        user_file_view.additional_properties = d
        return user_file_view

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
