from __future__ import annotations

import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from .. import types

T = TypeVar("T", bound="ShoppingListEntryBulk")


@_attrs_define
class ShoppingListEntryBulk:
    """
    Attributes:
        ids (list[Any]):
        checked (bool):
        timestamp (datetime.datetime):
    """

    ids: list[Any]
    checked: bool
    timestamp: datetime.datetime
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        ids = self.ids

        checked = self.checked

        timestamp = self.timestamp.isoformat()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "ids": ids,
                "checked": checked,
                "timestamp": timestamp,
            }
        )

        return field_dict

    def to_multipart(self) -> types.RequestFiles:
        files: types.RequestFiles = []

        for ids_item_element in self.ids:
            files.append(("ids", (None, str(ids_item_element).encode(), "text/plain")))

        files.append(("checked", (None, str(self.checked).encode(), "text/plain")))

        files.append(("timestamp", (None, self.timestamp.isoformat().encode(), "text/plain")))

        for prop_name, prop in self.additional_properties.items():
            files.append((prop_name, (None, str(prop).encode(), "text/plain")))

        return files

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        ids = cast(list[Any], d.pop("ids"))

        checked = d.pop("checked")

        timestamp = isoparse(d.pop("timestamp"))

        shopping_list_entry_bulk = cls(
            ids=ids,
            checked=checked,
            timestamp=timestamp,
        )

        shopping_list_entry_bulk.additional_properties = d
        return shopping_list_entry_bulk

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
